<?php
namespace Drupal\site_guardian\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

use Drupal\site_guardian\Services\SiteGuardianService;

/**
 * Provides route responses for the Example module.
 */
class SiteGuardianController extends ControllerBase {

  protected $site_guardian;
  protected $site_guardian_key;

  public function __construct(SiteGuardianService $site_guardian, $site_guardian_key) {

    $this->site_guardian = $site_guardian;
    $this->site_guardian_key = $site_guardian_key;
  }

  public static function create(ContainerInterface $container) {

    $site_guardian = $container->get('site_guardian.SiteGuardianService');
    $requestStack = $container->get('request_stack');
    
    $site_guardian_key = $requestStack->getCurrentRequest()->query->get('site_guardian_key');

    return new static($site_guardian, $site_guardian_key);
  }

  /**
   * Gets a list of all enabled projects.
   */
  public function listEnabledModules() {

    \Drupal::logger('site_guardian')->notice("Received request for enabled modules (List).");

    $project_list = \Drupal::service('update.manager')->getProjects();

    $formatted_project_list = '';

    foreach ($project_list as $project) {
      $formatted_project_list.= '<p>' . $project['info']['name'] . ' - Version: ' . $project['info']['version'] . '</p>';
    }

    return [
      '#markup' => $formatted_project_list,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
  }

  /**
   * Outputs a basic list of enabled projects in JSON.
   */
  public function listEnabledModulesJSON() {

    \Drupal::logger('site_guardian')->notice("Received request for enabled modules (JSON).");

    $project_list = \Drupal::service('update.manager')->getProjects();

    return new JsonResponse($project_list);
  }

  /**
   * Outputs a JSON list of version info for Drupal installation, PHP and database (amongst other things).
   */
  public function getSiteStatusReport() {

    \Drupal::logger('site_guardian')->notice("Received request for status report.");

    $status_report_info = \Drupal::service('system.manager')->listRequirements();

    return new JsonResponse($status_report_info);
  }

  /**
   * Output a JSON list of enabled projects, versions and recommended updates, as well as other project data.
   */

  public function listEnabledModulesAndUpdates() {

    \Drupal::logger('site_guardian')->notice("Received request for enabled modules and updates.");

    $projects = $this->site_guardian->getEnabledModulesAndUpdates();

    return new JsonResponse($projects);
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account) {
    return ($this->site_guardian->accessAllowed($this->site_guardian_key)) ? AccessResult::allowed() : AccessResult::forbidden();
  }
}
